@@ -69,7 +69,7 @@ def dict_or_array_dict(value):
     if isinstance(value, Dictionary):
         return [value.as_dict()]
     if isinstance(value, Array):
-        return [v.as_list() for v in value]
+        return [v for v in value.as_list()]
     raise NotImplementedError(value)
 
 
@@ -383,7 +383,14 @@ class PdfImage(PdfImageBase):
             iccstream = self._iccstream
             iccbuffer = iccstream.get_stream_buffer()
             iccbytesio = BytesIO(iccbuffer)
-            self._icc = ImageCms.ImageCmsProfile(iccbytesio)
+            try:
+                self._icc = ImageCms.ImageCmsProfile(iccbytesio)
+            except OSError as e:
+                if str(e) == 'cannot open profile from string':
+                    # ICC profile is corrupt
+                    raise UnsupportedImageTypeError(
+                        "ICC profile corrupt or not readable"
+                    ) from e
         return self._icc
 
     def _extract_direct(self, *, stream):
