@@ -2,6 +2,7 @@ import json
 import sys
 from copy import copy
 from decimal import Decimal, InvalidOperation
+from distutils.version import LooseVersion
 from math import isclose, isfinite
 from zlib import compress
 
@@ -285,9 +286,14 @@ class TestRepr:
                 '/Dictionary': Dictionary({'/Color': 'Red'}),
             }
         )
-        expected = """\
+        if LooseVersion(pikepdf.__libqpdf_version__) >= LooseVersion('10.2.0'):
+            short_pi = '3.14'
+        else:
+            short_pi = '3.140000'
+        expected = (
+            """\
             pikepdf.Dictionary({
-                "/Array": [ 1, 2, Decimal('3.140000') ],
+                "/Array": [ 1, 2, Decimal('%s') ],
                 "/Boolean": True,
                 "/Dictionary": {
                     "/Color": "Red"
@@ -298,6 +304,8 @@ class TestRepr:
                 "/String": "hi"
             })
         """
+            % short_pi
+        )
 
         def strip_all_whitespace(s):
             return ''.join(s.split())
@@ -420,7 +428,7 @@ def test_json():
     json_bytes = d.to_json(False)
     as_dict = json.loads(json_bytes)
     assert as_dict == {
-        "/Array": [1, 2, 3.140000],
+        "/Array": [1, 2, 3.14],
         "/Boolean": True,
         "/Dictionary": {"/Color": "Red"},
         "/Integer": 42,
@@ -437,7 +445,8 @@ def stream_object():
 
 @pytest.fixture
 def sandwich(resources):
-    return Pdf.open(resources / 'sandwich.pdf')
+    with Pdf.open(resources / 'sandwich.pdf') as pdf:
+        yield pdf
 
 
 class TestStreamReadWrite:
@@ -605,3 +614,25 @@ def test_stream_bad_params():
     p = pikepdf.new()
     with pytest.raises(TypeError, match='data'):
         Stream(p)
+
+
+def test_stream_no_dangling_stream_on_failure():
+    p = pikepdf.new()
+    num_objects = len(p.objects)
+    with pytest.raises(AttributeError):
+        Stream(p, b'3.14159', ['Not a mapping object'])
+    assert len(p.objects) == num_objects, "A dangling object was created"
+
+
+def test_dict_of_dict():
+    d = Dictionary(One=1, Two=2)
+    d2 = Dictionary(d)
+    assert d == d2
+    assert d is not d2
+
+
+def test_array_of_array():
+    a = Array([1, 2])
+    a2 = Array(a)
+    assert a == a2
+    assert a is not a2
